Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Core of the crate - PTX assembly build controller.

Implementations

Source

impl Builder

pub fn new<P: AsRef<Path>>(path: P) -> Result<Self>

Construct a builder for device crate at path.

Can also be the same crate, for single-source mode:

use ptx_builder::prelude::*;

match Builder::new(".")?.build()? {
    BuildStatus::Success(output) => {
        // do something with the output...
    }

    BuildStatus::NotNeeded => {
        // ...
    }
}
pub fn is_build_needed() -> bool

Returns bool indicating whether the actual build is needed.

Behavior is consistent with BuildStatus::NotNeeded.

pub fn disable_colors(self) -> Self

Disable colors for internal calls to cargo.

pub fn set_profile(self, profile: Profile) -> Self

Set build profile.

pub fn set_crate_type(self, crate_type: CrateType) -> Self

Set crate type that needs to be built.

Mandatory for mixed crates - that have both lib.rs and main.rs, otherwise Cargo won’t know which to build:

error: extra arguments to `rustc` can only be passed to one target, consider filtering
the package by passing e.g. `--lib` or `--bin NAME` to specify a single target
pub fn build(&self) -> Result<BuildStatus<'_>>

Performs an actual build: runs cargo with proper flags and environment.